from concentrator.smev3_v321.models import OrderRequest

from .constants import DECLARATION_CHANGED
from .enums import PendingUpdateOrderRequestSourceVersionEnum
from .helpers import DispatchOrderRequestSMEV3RequestManager


def send_update_order_request(
        declaration_id, declaration_changes_rows, reject_changes_comment,
        ext_result
):
    """Точка расширения для отправки UpdateOrderRequest после
    отклонения изменений с концентратора.

    :param declaration_id: Идентификатор заявления
    :type declaration_id: int
    :param declaration_changes_rows: Список изменений заявления
    :type declaration_changes_rows: list
    :param reject_changes_comment: Комментарий причины отклонения изменений
    :type reject_changes_comment: str

    """

    try:
        order_request = (
            OrderRequest.objects.get(declaration_id=declaration_id))
    except OrderRequest.DoesNotExist:
        return

    DispatchOrderRequestSMEV3RequestManager(
        order_request, PendingUpdateOrderRequestSourceVersionEnum.V_0,
        {
            'declaration_id': declaration_id,
            'event': DECLARATION_CHANGED,
            'declaration_changes_rows': declaration_changes_rows,
            'reject_changes_comment': reject_changes_comment,
        }).run()
